import { IsBoolean, IsInt, IsOptional, IsString } from 'class-validator';
import { ScanStation } from '../entities/ScanStation';

/**
 * This classed is used to create a new StatsClient entity from a json body (post request).
 */
export class UpdateScanStation {
    /**
     * The updated station's id.
     * This shouldn't have changed but it is here in case anyone ever wants to enable id changes (whyever they would want to).
     */
    @IsInt()
    id: number;

    /**
     * The updated station's description.
     */
    @IsString()
    @IsOptional()
    description?: string;

    /**
     * Is this station enabled?
     */
    @IsBoolean()
    @IsOptional()
    enabled?: boolean = true;

    /**
     * Converts this to a ScanStation entity.
     * TODO:
     */
    public async updateStation(station: ScanStation): Promise<ScanStation> {
        station.description = this.description;
        station.enabled = this.enabled;

        return station;
    }
}